/// <reference types="node" />
import { Provider } from "@project-serum/anchor";
import { MintInfo } from "@solana/spl-token";
import { PublicKey, Signer, TransactionInstruction } from "@solana/web3.js";
import { InstructionResult } from ".";
import { ArweaveEnv } from "./arweave";
import { Creator, Data, Edition, IMetadataExtension, MasterEditionV1, MasterEditionV2, Metadata } from "./metadata";
export interface ICreateArweaveUrlArgs {
    payer?: PublicKey;
    name: string;
    symbol: string;
    description?: string;
    image?: string;
    creators?: Creator[];
    files?: Map<string, Buffer>;
    env: ArweaveEnv;
    uploadUrl: string;
}
export interface ICreateMetadataInstructionsArgs {
    data: Data;
    authority?: PublicKey;
    mint: PublicKey;
    payer?: PublicKey;
}
export interface IUpdateMetadataInstructionsArgs {
    data?: Data | null;
    authority?: PublicKey | null;
    metadata: PublicKey;
    payer?: PublicKey;
}
export interface ITokenWithMeta {
    metadataKey?: PublicKey;
    metadata?: Metadata;
    mint?: MintInfo;
    edition?: Edition;
    masterEdition?: MasterEditionV1 | MasterEditionV2;
    data?: IMetadataExtension;
    image?: string;
    description?: string;
}
export declare class SplTokenMetadata {
    provider: Provider;
    static init(provider: Provider): Promise<SplTokenMetadata>;
    constructor(opts: {
        provider: Provider;
    });
    static getArweaveMetadata(uri: string | undefined): Promise<IMetadataExtension | undefined>;
    static getImage(uri: string | undefined): Promise<string | undefined>;
    static getEdition(tokenMint: PublicKey): Promise<PublicKey>;
    getEditionInfo(metadata: Metadata | undefined): Promise<{
        edition?: Edition;
        masterEdition?: MasterEditionV1 | MasterEditionV2;
    }>;
    getMetadata(metadataKey: PublicKey): Promise<Metadata | null>;
    getTokenMetadata(metadataKey: PublicKey): Promise<ITokenWithMeta>;
    sendInstructions(instructions: TransactionInstruction[], signers: Signer[], payer?: PublicKey): Promise<string>;
    presignCreateArweaveUrlInstructions({ name, symbol, description, image, creators, files, payer, env, uploadUrl }: ICreateArweaveUrlArgs): Promise<InstructionResult<{
        files: Map<string, Buffer>;
    }>>;
    presignCreateArweaveUrl(args: ICreateArweaveUrlArgs): Promise<{
        files: Map<string, Buffer>;
        txid: string;
    }>;
    getArweaveUrl({ txid, mint, files, uploadUrl, env }: {
        env: ArweaveEnv;
        uploadUrl?: string;
        txid: string;
        mint: PublicKey;
        files?: Map<string, Buffer>;
    }): Promise<string>;
    createMetadataInstructions({ data, authority, mint, payer }: ICreateMetadataInstructionsArgs): Promise<InstructionResult<{
        metadata: PublicKey;
    }>>;
    createMetadata(args: ICreateMetadataInstructionsArgs): Promise<{
        metadata: PublicKey;
    }>;
    updateMetadataInstructions({ data, authority, metadata }: IUpdateMetadataInstructionsArgs): Promise<InstructionResult<{
        metadata: PublicKey;
    }>>;
    updateMetadata(args: IUpdateMetadataInstructionsArgs): Promise<{
        metadata: PublicKey;
    }>;
}
//# sourceMappingURL=splTokenMetadata.d.ts.map